@@ -91,14 +91,14 @@ class TestPloneApiContent(unittest.TestCase):
         with self.assertRaises(MissingParameterError):
             api.content.create()
 
-        # Check the contraints for the type container
+        # Check the constraints for the type container
         with self.assertRaises(MissingParameterError):
             api.content.create(
                 type='Document',
                 id='test-doc',
             )
 
-        # Check the contraints for the type parameter
+        # Check the constraints for the type parameter
         container = mock.Mock()
         with self.assertRaises(MissingParameterError):
             api.content.create(
@@ -106,13 +106,13 @@ class TestPloneApiContent(unittest.TestCase):
                 id='test-doc',
             )
 
-        # Check the contraints for id and title parameters
+        # Check the constraints for id and title parameters
         with self.assertRaises(MissingParameterError):
             api.content.create(
                 container=container, type='Document'
             )
 
-        # Check the contraints for allowed types in the container
+        # Check the constraints for allowed types in the container
         container = self.events
         with self.assertRaises(InvalidParameterError):
             api.content.create(
@@ -121,7 +121,7 @@ class TestPloneApiContent(unittest.TestCase):
                 id='test-foo',
             )
 
-        # Check the contraints for allowed types in the container if
+        # Check the constraints for allowed types in the container if
         # the container is the portal
         container = self.portal
         with self.assertRaises(InvalidParameterError) as cm:
@@ -138,7 +138,7 @@ class TestPloneApiContent(unittest.TestCase):
             cm.exception.message
         )
 
-        # Check the contraints for allowed types in the container
+        # Check the constraints for allowed types in the container
         # Create a folder
         folder = api.content.create(
             container=container, type='Folder', id='test-folder')
@@ -401,6 +401,18 @@ class TestPloneApiContent(unittest.TestCase):
         assert (container['events']['about'] and
                 container['events']['about'] == about)
 
+    def test_move_no_move_if_target_is_source_parent(self):
+        """Test that trying to move an object to its parent is a noop"""
+
+        target = self.contact.aq_parent
+        with mock.patch.object(target, 'manage_pasteObjects'):
+            api.content.move(
+                source=self.contact,
+                target=target,
+            )
+
+            self.assertFalse(target.manage_pasteObjects.called)
+
     def test_rename_constraints(self):
         """Test the constraints for rename content."""
         from plone.api.exc import MissingParameterError
@@ -952,7 +964,7 @@ class TestPloneApiContent(unittest.TestCase):
         )
         self.assertEqual(aq_base(view.context), aq_base(self.blog))
         self.assertEqual(view.__name__, 'plone')
-        self.assertTrue(hasattr(view, 'getIcon'))
+        self.assertTrue(hasattr(view, 'toLocalizedTime'))
 
         # Try another standard view.
         view = api.content.get_view(
