@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 """Tests for plone.api.group."""
 
-from Products.CMFCore.utils import getToolByName
 from plone import api
 from plone.api.tests.base import INTEGRATION_TESTING
+from Products.CMFCore.utils import getToolByName
 
 import mock
 import unittest
@@ -21,8 +21,8 @@ class TestPloneApiGroup(unittest.TestCase):
         self.portal_membership = getToolByName(
             self.portal, 'portal_membership')
 
-    def test_create_contraints(self):
-        """Test the contraints for creating a group."""
+    def test_create_constraints(self):
+        """Test the constraints for creating a group."""
         from plone.api.exc import MissingParameterError
         with self.assertRaises(MissingParameterError):
             api.group.create()
@@ -143,7 +143,20 @@ class TestPloneApiGroup(unittest.TestCase):
         with self.assertRaises(UserNotFoundError):
             api.group.get_groups(username='theurbanspaceman')
 
-    def test_delete_contraints(self):
+    def test_get_groups_anonymous(self):
+        from AccessControl.users import nobody
+        # In test the anonymous user is aq wrapped in /plone/acl_users
+        # > self.portal.acl_users in api.user.get_current().aq_chain
+        # >>> True
+        # In practice is is aq wrapped in /acl_users
+        # > self.context.acl_users in api.user.get_current().aq_chain
+        # >>> False
+        # We'll force the user into /acl_users, which has no portal_groups.
+        user = nobody.__of__(api.portal.get().__parent__.acl_users)
+        groups = api.group.get_groups(user=user)
+        self.assertEqual(groups, [])  # should be empty
+
+    def test_delete_constraints(self):
         """Test deleting a group without passing parameters."""
         from plone.api.exc import MissingParameterError
         with self.assertRaises(MissingParameterError):
@@ -176,7 +189,7 @@ class TestPloneApiGroup(unittest.TestCase):
         api.group.delete(group=group)
         self.assertIsNone(api.group.get('bacon'))
 
-    def test_add_user_contraints(self):
+    def test_add_user_constraints(self):
         """Test the constraints when a user is added to a group."""
         from plone.api.exc import InvalidParameterError
         with self.assertRaises(InvalidParameterError):
@@ -240,7 +253,7 @@ class TestPloneApiGroup(unittest.TestCase):
 
         self.assertIn('jane', group.getMemberIds())
 
-    def test_remove_user_contraints(self):
+    def test_remove_user_constraints(self):
         """Test the constraints when a user is removed from a group."""
         from plone.api.exc import InvalidParameterError
         from plone.api.exc import MissingParameterError
